import asyncio

import aiohttp
import base_detector


class LocalMoonrakerDetector(base_detector.BaseDetector):

    IP = "127.0.0.1"
    HTTP_PORT = 7125
    PATH = "/server/info"
    URL = "http://" + IP + ":" + str(HTTP_PORT) + PATH
    TIMEOUT = 0.2
    LOOP_SLEEP = 1
    PRINTER_ID_LIST = [{'VID': 'MNRK', 'PID': 'GENE', 'SNR': '127.0.0.1', 'IP': '127.0.0.1'}]
    CONFLICTS = ['KlipperDetector']

    def __init__(self, parent=None):
        super().__init__(parent)
        self.parent = parent
        try:
            self.loop = asyncio.get_event_loop()
        except RuntimeError:
            self.loop = asyncio.new_event_loop()
            asyncio.set_event_loop(self.loop)
        self.session = aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=self.TIMEOUT))

    def get_printers_list(self):
        self.loop.run_until_complete(self.detection_coro())
        return self.devices_list

    async def detection_coro(self):
        try:
            async with self.session.get(self.URL) as resp:
                if resp.ok:
                    resp_dict = await resp.json()
                    moonraker_version = resp_dict.get('result', {}).get('moonraker_version')
                    if moonraker_version:
                        self.devices_list = self.PRINTER_ID_LIST
                        return
            self.devices_list = []
        except:
            self.devices_list = []
            #self.logger.exception('Exception in detection coroutine: ')
